cmd

package
v1.27.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: MIT Imports: 25 Imported by: 0

Documentation

Overview

Package cmd implements the root command and command factory for the caproni CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateApp

func CreateApp(embeddedVersions map[string]string) *cli.Command

CreateApp creates and configures the CLI application.

Types

This section is empty.

Directories

Path Synopsis
Package config implements configuration management commands.
Package config implements configuration management commands.
Package deploy implements the deploy command for deploying Helm charts to the cluster.
Package deploy implements the deploy command for deploying Helm charts to the cluster.
Package destroy implements the destroy command for destroying the Caproni cluster.
Package destroy implements the destroy command for destroying the Caproni cluster.
Package down implements the down command for stopping the Caproni cluster.
Package down implements the down command for stopping the Caproni cluster.
Package main provides a tool for generating documentation for the caproni CLI.
Package main provides a tool for generating documentation for the caproni CLI.
Package run implements the run command for running reloaders in edit mode.
Package run implements the run command for running reloaders in edit mode.
Package status implements the status command for displaying service status.
Package status implements the status command for displaying service status.
Package up implements the up command for starting the Caproni cluster.
Package up implements the up command for starting the Caproni cluster.
Package update implements the update command for updating repository source code.
Package update implements the update command for updating repository source code.
Package updateetchosts implements the update-etc-hosts command for managing /etc/hosts entries.
Package updateetchosts implements the update-etc-hosts command for managing /etc/hosts entries.
Package version implements the version command for displaying build information.
Package version implements the version command for displaying build information.

Jump to