executor

package
v1.27.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package executor provides auto-generated mocks for the executor.CommandRunner interface. This package should only be imported in test files.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockCommandRunner

type MockCommandRunner struct {
	mock.Mock
}

MockCommandRunner is an autogenerated mock type for the CommandRunner type

func NewMockCommandRunner

func NewMockCommandRunner(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockCommandRunner

NewMockCommandRunner creates a new instance of MockCommandRunner. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockCommandRunner) EXPECT

func (*MockCommandRunner) ExecStreamedCommand

func (_mock *MockCommandRunner) ExecStreamedCommand(ctx context.Context, opts *executor.ExecStreamedOpts, name string, args ...string) error

ExecStreamedCommand provides a mock function for the type MockCommandRunner

func (*MockCommandRunner) LookPath

func (_mock *MockCommandRunner) LookPath(file string) (string, error)

LookPath provides a mock function for the type MockCommandRunner

func (*MockCommandRunner) ReadStdout

func (_mock *MockCommandRunner) ReadStdout(ctx context.Context, name string, args ...string) (string, error)

ReadStdout provides a mock function for the type MockCommandRunner

func (*MockCommandRunner) Run

func (_mock *MockCommandRunner) Run(ctx context.Context, name string, args []string, opts *executor.Options) *executor.Result

Run provides a mock function for the type MockCommandRunner

func (*MockCommandRunner) RunInRepository

func (_mock *MockCommandRunner) RunInRepository(ctx context.Context, caproniConfig *v2.CaproniConfig, repoConfig *v2.RepositoryConfig, name string, args []string, opts *executor.ExecStreamedOpts) error

RunInRepository provides a mock function for the type MockCommandRunner

type MockCommandRunner_ExecStreamedCommand_Call

type MockCommandRunner_ExecStreamedCommand_Call struct {
	*mock.Call
}

MockCommandRunner_ExecStreamedCommand_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ExecStreamedCommand'

func (*MockCommandRunner_ExecStreamedCommand_Call) Return

func (*MockCommandRunner_ExecStreamedCommand_Call) Run

func (*MockCommandRunner_ExecStreamedCommand_Call) RunAndReturn

type MockCommandRunner_Expecter

type MockCommandRunner_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockCommandRunner_Expecter) ExecStreamedCommand

func (_e *MockCommandRunner_Expecter) ExecStreamedCommand(ctx interface{}, opts interface{}, name interface{}, args ...interface{}) *MockCommandRunner_ExecStreamedCommand_Call

ExecStreamedCommand is a helper method to define mock.On call

  • ctx context.Context
  • opts *executor.ExecStreamedOpts
  • name string
  • args ...string

func (*MockCommandRunner_Expecter) LookPath

func (_e *MockCommandRunner_Expecter) LookPath(file interface{}) *MockCommandRunner_LookPath_Call

LookPath is a helper method to define mock.On call

  • file string

func (*MockCommandRunner_Expecter) ReadStdout

func (_e *MockCommandRunner_Expecter) ReadStdout(ctx interface{}, name interface{}, args ...interface{}) *MockCommandRunner_ReadStdout_Call

ReadStdout is a helper method to define mock.On call

  • ctx context.Context
  • name string
  • args ...string

func (*MockCommandRunner_Expecter) Run

func (_e *MockCommandRunner_Expecter) Run(ctx interface{}, name interface{}, args interface{}, opts interface{}) *MockCommandRunner_Run_Call

Run is a helper method to define mock.On call

  • ctx context.Context
  • name string
  • args []string
  • opts *executor.Options

func (*MockCommandRunner_Expecter) RunInRepository

func (_e *MockCommandRunner_Expecter) RunInRepository(ctx interface{}, caproniConfig interface{}, repoConfig interface{}, name interface{}, args interface{}, opts interface{}) *MockCommandRunner_RunInRepository_Call

RunInRepository is a helper method to define mock.On call

  • ctx context.Context
  • caproniConfig *v2.CaproniConfig
  • repoConfig *v2.RepositoryConfig
  • name string
  • args []string
  • opts *executor.ExecStreamedOpts

type MockCommandRunner_LookPath_Call

type MockCommandRunner_LookPath_Call struct {
	*mock.Call
}

MockCommandRunner_LookPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'LookPath'

func (*MockCommandRunner_LookPath_Call) Return

func (*MockCommandRunner_LookPath_Call) Run

func (*MockCommandRunner_LookPath_Call) RunAndReturn

type MockCommandRunner_ReadStdout_Call

type MockCommandRunner_ReadStdout_Call struct {
	*mock.Call
}

MockCommandRunner_ReadStdout_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ReadStdout'

func (*MockCommandRunner_ReadStdout_Call) Return

func (*MockCommandRunner_ReadStdout_Call) Run

func (*MockCommandRunner_ReadStdout_Call) RunAndReturn

type MockCommandRunner_RunInRepository_Call

type MockCommandRunner_RunInRepository_Call struct {
	*mock.Call
}

MockCommandRunner_RunInRepository_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RunInRepository'

func (*MockCommandRunner_RunInRepository_Call) Return

func (*MockCommandRunner_RunInRepository_Call) Run

func (_c *MockCommandRunner_RunInRepository_Call) Run(run func(ctx context.Context, caproniConfig *v2.CaproniConfig, repoConfig *v2.RepositoryConfig, name string, args []string, opts *executor.ExecStreamedOpts)) *MockCommandRunner_RunInRepository_Call

func (*MockCommandRunner_RunInRepository_Call) RunAndReturn

func (_c *MockCommandRunner_RunInRepository_Call) RunAndReturn(run func(ctx context.Context, caproniConfig *v2.CaproniConfig, repoConfig *v2.RepositoryConfig, name string, args []string, opts *executor.ExecStreamedOpts) error) *MockCommandRunner_RunInRepository_Call

type MockCommandRunner_Run_Call

type MockCommandRunner_Run_Call struct {
	*mock.Call
}

MockCommandRunner_Run_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Run'

func (*MockCommandRunner_Run_Call) Return

func (*MockCommandRunner_Run_Call) Run

func (*MockCommandRunner_Run_Call) RunAndReturn

func (_c *MockCommandRunner_Run_Call) RunAndReturn(run func(ctx context.Context, name string, args []string, opts *executor.Options) *executor.Result) *MockCommandRunner_Run_Call

Jump to