Documentation
¶
Overview ¶
Package executor provides auto-generated mocks for the executor.CommandRunner interface. This package should only be imported in test files.
Index ¶
- type MockCommandRunner
- func (_m *MockCommandRunner) EXPECT() *MockCommandRunner_Expecter
- func (_mock *MockCommandRunner) ExecStreamedCommand(ctx context.Context, opts *executor.ExecStreamedOpts, name string, ...) error
- func (_mock *MockCommandRunner) LookPath(file string) (string, error)
- func (_mock *MockCommandRunner) ReadStdout(ctx context.Context, name string, args ...string) (string, error)
- func (_mock *MockCommandRunner) Run(ctx context.Context, name string, args []string, opts *executor.Options) *executor.Result
- func (_mock *MockCommandRunner) RunInRepository(ctx context.Context, caproniConfig *v2.CaproniConfig, ...) error
- type MockCommandRunner_ExecStreamedCommand_Call
- func (_c *MockCommandRunner_ExecStreamedCommand_Call) Return(err error) *MockCommandRunner_ExecStreamedCommand_Call
- func (_c *MockCommandRunner_ExecStreamedCommand_Call) Run(...) *MockCommandRunner_ExecStreamedCommand_Call
- func (_c *MockCommandRunner_ExecStreamedCommand_Call) RunAndReturn(...) *MockCommandRunner_ExecStreamedCommand_Call
- type MockCommandRunner_Expecter
- func (_e *MockCommandRunner_Expecter) ExecStreamedCommand(ctx interface{}, opts interface{}, name interface{}, args ...interface{}) *MockCommandRunner_ExecStreamedCommand_Call
- func (_e *MockCommandRunner_Expecter) LookPath(file interface{}) *MockCommandRunner_LookPath_Call
- func (_e *MockCommandRunner_Expecter) ReadStdout(ctx interface{}, name interface{}, args ...interface{}) *MockCommandRunner_ReadStdout_Call
- func (_e *MockCommandRunner_Expecter) Run(ctx interface{}, name interface{}, args interface{}, opts interface{}) *MockCommandRunner_Run_Call
- func (_e *MockCommandRunner_Expecter) RunInRepository(ctx interface{}, caproniConfig interface{}, repoConfig interface{}, ...) *MockCommandRunner_RunInRepository_Call
- type MockCommandRunner_LookPath_Call
- func (_c *MockCommandRunner_LookPath_Call) Return(s string, err error) *MockCommandRunner_LookPath_Call
- func (_c *MockCommandRunner_LookPath_Call) Run(run func(file string)) *MockCommandRunner_LookPath_Call
- func (_c *MockCommandRunner_LookPath_Call) RunAndReturn(run func(file string) (string, error)) *MockCommandRunner_LookPath_Call
- type MockCommandRunner_ReadStdout_Call
- func (_c *MockCommandRunner_ReadStdout_Call) Return(s string, err error) *MockCommandRunner_ReadStdout_Call
- func (_c *MockCommandRunner_ReadStdout_Call) Run(run func(ctx context.Context, name string, args ...string)) *MockCommandRunner_ReadStdout_Call
- func (_c *MockCommandRunner_ReadStdout_Call) RunAndReturn(run func(ctx context.Context, name string, args ...string) (string, error)) *MockCommandRunner_ReadStdout_Call
- type MockCommandRunner_RunInRepository_Call
- func (_c *MockCommandRunner_RunInRepository_Call) Return(err error) *MockCommandRunner_RunInRepository_Call
- func (_c *MockCommandRunner_RunInRepository_Call) Run(run func(ctx context.Context, caproniConfig *v2.CaproniConfig, ...)) *MockCommandRunner_RunInRepository_Call
- func (_c *MockCommandRunner_RunInRepository_Call) RunAndReturn(run func(ctx context.Context, caproniConfig *v2.CaproniConfig, ...) error) *MockCommandRunner_RunInRepository_Call
- type MockCommandRunner_Run_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockCommandRunner ¶
MockCommandRunner is an autogenerated mock type for the CommandRunner type
func NewMockCommandRunner ¶
func NewMockCommandRunner(t interface {
mock.TestingT
Cleanup(func())
}) *MockCommandRunner
NewMockCommandRunner creates a new instance of MockCommandRunner. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockCommandRunner) EXPECT ¶
func (_m *MockCommandRunner) EXPECT() *MockCommandRunner_Expecter
func (*MockCommandRunner) ExecStreamedCommand ¶
func (_mock *MockCommandRunner) ExecStreamedCommand(ctx context.Context, opts *executor.ExecStreamedOpts, name string, args ...string) error
ExecStreamedCommand provides a mock function for the type MockCommandRunner
func (*MockCommandRunner) LookPath ¶
func (_mock *MockCommandRunner) LookPath(file string) (string, error)
LookPath provides a mock function for the type MockCommandRunner
func (*MockCommandRunner) ReadStdout ¶
func (_mock *MockCommandRunner) ReadStdout(ctx context.Context, name string, args ...string) (string, error)
ReadStdout provides a mock function for the type MockCommandRunner
func (*MockCommandRunner) Run ¶
func (_mock *MockCommandRunner) Run(ctx context.Context, name string, args []string, opts *executor.Options) *executor.Result
Run provides a mock function for the type MockCommandRunner
func (*MockCommandRunner) RunInRepository ¶
func (_mock *MockCommandRunner) RunInRepository(ctx context.Context, caproniConfig *v2.CaproniConfig, repoConfig *v2.RepositoryConfig, name string, args []string, opts *executor.ExecStreamedOpts) error
RunInRepository provides a mock function for the type MockCommandRunner
type MockCommandRunner_ExecStreamedCommand_Call ¶
MockCommandRunner_ExecStreamedCommand_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ExecStreamedCommand'
func (*MockCommandRunner_ExecStreamedCommand_Call) Return ¶
func (_c *MockCommandRunner_ExecStreamedCommand_Call) Return(err error) *MockCommandRunner_ExecStreamedCommand_Call
func (*MockCommandRunner_ExecStreamedCommand_Call) Run ¶
func (_c *MockCommandRunner_ExecStreamedCommand_Call) Run(run func(ctx context.Context, opts *executor.ExecStreamedOpts, name string, args ...string)) *MockCommandRunner_ExecStreamedCommand_Call
func (*MockCommandRunner_ExecStreamedCommand_Call) RunAndReturn ¶
func (_c *MockCommandRunner_ExecStreamedCommand_Call) RunAndReturn(run func(ctx context.Context, opts *executor.ExecStreamedOpts, name string, args ...string) error) *MockCommandRunner_ExecStreamedCommand_Call
type MockCommandRunner_Expecter ¶
type MockCommandRunner_Expecter struct {
// contains filtered or unexported fields
}
func (*MockCommandRunner_Expecter) ExecStreamedCommand ¶
func (_e *MockCommandRunner_Expecter) ExecStreamedCommand(ctx interface{}, opts interface{}, name interface{}, args ...interface{}) *MockCommandRunner_ExecStreamedCommand_Call
ExecStreamedCommand is a helper method to define mock.On call
- ctx context.Context
- opts *executor.ExecStreamedOpts
- name string
- args ...string
func (*MockCommandRunner_Expecter) LookPath ¶
func (_e *MockCommandRunner_Expecter) LookPath(file interface{}) *MockCommandRunner_LookPath_Call
LookPath is a helper method to define mock.On call
- file string
func (*MockCommandRunner_Expecter) ReadStdout ¶
func (_e *MockCommandRunner_Expecter) ReadStdout(ctx interface{}, name interface{}, args ...interface{}) *MockCommandRunner_ReadStdout_Call
ReadStdout is a helper method to define mock.On call
- ctx context.Context
- name string
- args ...string
func (*MockCommandRunner_Expecter) Run ¶
func (_e *MockCommandRunner_Expecter) Run(ctx interface{}, name interface{}, args interface{}, opts interface{}) *MockCommandRunner_Run_Call
Run is a helper method to define mock.On call
- ctx context.Context
- name string
- args []string
- opts *executor.Options
func (*MockCommandRunner_Expecter) RunInRepository ¶
func (_e *MockCommandRunner_Expecter) RunInRepository(ctx interface{}, caproniConfig interface{}, repoConfig interface{}, name interface{}, args interface{}, opts interface{}) *MockCommandRunner_RunInRepository_Call
RunInRepository is a helper method to define mock.On call
- ctx context.Context
- caproniConfig *v2.CaproniConfig
- repoConfig *v2.RepositoryConfig
- name string
- args []string
- opts *executor.ExecStreamedOpts
type MockCommandRunner_LookPath_Call ¶
MockCommandRunner_LookPath_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'LookPath'
func (*MockCommandRunner_LookPath_Call) Return ¶
func (_c *MockCommandRunner_LookPath_Call) Return(s string, err error) *MockCommandRunner_LookPath_Call
func (*MockCommandRunner_LookPath_Call) Run ¶
func (_c *MockCommandRunner_LookPath_Call) Run(run func(file string)) *MockCommandRunner_LookPath_Call
func (*MockCommandRunner_LookPath_Call) RunAndReturn ¶
func (_c *MockCommandRunner_LookPath_Call) RunAndReturn(run func(file string) (string, error)) *MockCommandRunner_LookPath_Call
type MockCommandRunner_ReadStdout_Call ¶
MockCommandRunner_ReadStdout_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ReadStdout'
func (*MockCommandRunner_ReadStdout_Call) Return ¶
func (_c *MockCommandRunner_ReadStdout_Call) Return(s string, err error) *MockCommandRunner_ReadStdout_Call
func (*MockCommandRunner_ReadStdout_Call) Run ¶
func (_c *MockCommandRunner_ReadStdout_Call) Run(run func(ctx context.Context, name string, args ...string)) *MockCommandRunner_ReadStdout_Call
func (*MockCommandRunner_ReadStdout_Call) RunAndReturn ¶
func (_c *MockCommandRunner_ReadStdout_Call) RunAndReturn(run func(ctx context.Context, name string, args ...string) (string, error)) *MockCommandRunner_ReadStdout_Call
type MockCommandRunner_RunInRepository_Call ¶
MockCommandRunner_RunInRepository_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RunInRepository'
func (*MockCommandRunner_RunInRepository_Call) Return ¶
func (_c *MockCommandRunner_RunInRepository_Call) Return(err error) *MockCommandRunner_RunInRepository_Call
func (*MockCommandRunner_RunInRepository_Call) Run ¶
func (_c *MockCommandRunner_RunInRepository_Call) Run(run func(ctx context.Context, caproniConfig *v2.CaproniConfig, repoConfig *v2.RepositoryConfig, name string, args []string, opts *executor.ExecStreamedOpts)) *MockCommandRunner_RunInRepository_Call
func (*MockCommandRunner_RunInRepository_Call) RunAndReturn ¶
func (_c *MockCommandRunner_RunInRepository_Call) RunAndReturn(run func(ctx context.Context, caproniConfig *v2.CaproniConfig, repoConfig *v2.RepositoryConfig, name string, args []string, opts *executor.ExecStreamedOpts) error) *MockCommandRunner_RunInRepository_Call
type MockCommandRunner_Run_Call ¶
MockCommandRunner_Run_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Run'
func (*MockCommandRunner_Run_Call) Return ¶
func (_c *MockCommandRunner_Run_Call) Return(result *executor.Result) *MockCommandRunner_Run_Call
func (*MockCommandRunner_Run_Call) Run ¶
func (_c *MockCommandRunner_Run_Call) Run(run func(ctx context.Context, name string, args []string, opts *executor.Options)) *MockCommandRunner_Run_Call
func (*MockCommandRunner_Run_Call) RunAndReturn ¶
func (_c *MockCommandRunner_Run_Call) RunAndReturn(run func(ctx context.Context, name string, args []string, opts *executor.Options) *executor.Result) *MockCommandRunner_Run_Call